@@ -126,10 +126,8 @@ class FireServiceRotaOAuth():
 
          try:         
             oauth_client = oauthlib.oauth2.LegacyApplicationClient(self._client_id)
-            request_body = request_body = oauth_client.prepare_request_body(
-                     username=self._username, password=self._password)
             request_body = oauth_client.prepare_refresh_body(
-                     request_body, refresh_token=token_info['refresh_token'])
+                     refresh_token=token_info['refresh_token'])
             request_response = requests.post(url=self._authentication_url,
                      params=str.encode(request_body))
 
